@@ -7,35 +7,36 @@ import click
 from fideslog.sdk.python.client import AnalyticsClient
 
 import fidesctl
-from fidesctl.cli.utils import check_and_update_analytics_config
+from fidesctl.cli.utils import check_and_update_analytics_config, check_server
 from fidesctl.core.config import get_config
 
-from .annotate_commands import annotate
-from .core_commands import apply, evaluate, parse
-from .crud_commands import delete, get, ls
-from .db_commands import database
-from .export_commands import export
-from .generate_commands import generate
-from .scan_commands import scan
-from .util_comands import init, ping, webserver
-from .view_commands import view
+from .commands.annotate import annotate
+from .commands.core import apply, evaluate, parse
+from .commands.crud import delete, get, ls
+from .commands.db import database
+from .commands.export import export
+from .commands.generate import generate
+from .commands.scan import scan
+from .commands.util import init, status, webserver
+from .commands.view import view
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
-LOCAL_COMMANDS = [evaluate, parse, view]
+LOCAL_COMMANDS = [evaluate, parse, view, webserver]
 API_COMMANDS = [
     annotate,
     apply,
+    database,
     delete,
     export,
     generate,
-    scan,
     get,
     init,
-    database,
     ls,
-    ping,
-    webserver,
-] + LOCAL_COMMANDS
+    scan,
+    status,
+]
+ALL_COMMANDS = API_COMMANDS + LOCAL_COMMANDS
+VERSION = fidesctl.__version__
 
 
 @click.group(
@@ -43,7 +44,7 @@ API_COMMANDS = [
     invoke_without_command=True,
     name="fidesctl",
 )
-@click.version_option(version=fidesctl.__version__)
+@click.version_option(version=VERSION)
 @click.option(
     "--config-path",
     "-f",
@@ -75,11 +76,15 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
             cli.add_command(command)
     else:
         config.cli.local_mode = True
-    ctx.obj["CONFIG"] = config
 
+    ctx.obj["CONFIG"] = config
     if not ctx.invoked_subcommand:
         click.echo(cli.get_help(ctx))
 
+    # Check the server health and version if an API command is invoked
+    if ctx.invoked_subcommand in [command.name for command in API_COMMANDS]:
+        check_server(VERSION, config.cli.server_url)
+
     if ctx.invoked_subcommand != "init":  # init also handles this workflow
         check_and_update_analytics_config(ctx, config_path)
 
@@ -99,5 +104,5 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
 # This has to be done due to the dynamic way in which commands are added for the real CLI group
 cli_docs = cli
 
-for cli_command in API_COMMANDS:
+for cli_command in ALL_COMMANDS:
     cli_docs.add_command(cli_command)
